==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Wszystkie tematy");
define("_NOCOMMENTS","Bez komentarza");
define("_UCOMMENT","Komentarz");
define("_REVIEWS","Recenzje");
define("_SEARCHUSERS","Szukaj w bazie uytkownikw");
define("_SEARCHSECTIONS","Szukaj w sekcjach specjalnych");
define("_SEARCHREVIEWS","Szukaj w recenzjach");
define("_SEARCHIN","Szukaj w");
define("_ARTICLES","Artykuy");
define("_ALLAUTHORS","Wszyscy autorzy");
define("_ALL","Wszystko");
define("_WEEK","tydzie");
define("_WEEKS","tygodnie");
define("_MONTH","miesic");
define("_MONTHS","miesice");
define("_SEARCHON","Szukaj na:");
define("_SSTORIES","Artykuy");
define("_SSECTIONS","Sekcje");
define("_SUSERS","Uytkownicy");
define("_NOMATCHES","Brak rezultatw wyszukiwania");
define("_PREVMATCHES","poprzednie wyniki");
define("_NEXTMATCHES","nastpne wyniki");
define("_INSECTION","Artyku w sekcji");
define("_NONAME","Nie wpisano nazwy");
define("_SCOMMENTS","Komentarze");
define("_SEARCHRESULTS","Wyniki wyszukiwania");
define("_CONTRIBUTEDBY","Wsppraca");
define("_UCOMMENTS","Komentarze");
define("_MATCHTITLE","Szukaj wedug tytuu artykuu");
define("_MATCHTEXT","Szukaj wedug tekstu");
define("_MATCHBOTH","Szukaj wedug tytyu i tekstu");
define("_SREPLY","Odpowiedz");
define("_SREPLIES","Odpowiedzi");
define("_ATTACHART","Doczony do artykuu");
define("_PAGES","Strony");
define("_REVIEWSCORE","Wynik dla tej recenzji");
define("_PAGE","Strona");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Wszystkie tematy");
define("_NOCOMMENTS","Bez komentarza");
define("_UCOMMENT","Komentarz");
define("_REVIEWS","Recenzje");
define("_SEARCHUSERS","Szukaj w bazie uytkownikw");
define("_SEARCHSECTIONS","Szukaj w sekcjach specjalnych");
define("_SEARCHREVIEWS","Szukaj w recenzjach");
define("_SEARCHIN","Szukaj w");
define("_ARTICLES","Artykuy");
define("_ALLAUTHORS","Wszyscy autorzy");
define("_ALL","Wszystko");
define("_WEEK","tydzie");
define("_WEEKS","tygodnie");
define("_MONTH","miesic");
define("_MONTHS","miesice");
define("_SEARCHON","Szukaj na:");
define("_SSTORIES","Artykuy");
define("_SSECTIONS","Sekcje");
define("_SUSERS","Uytkownicy");
define("_NOMATCHES","Brak rezultatw wyszukiwania");
define("_PREVMATCHES","poprzednie wyniki");
define("_NEXTMATCHES","nastpne wyniki");
define("_INSECTION","Artyku w sekcji");
define("_NONAME","Nie wpisano nazwy");
define("_SCOMMENTS","Komentarze");
define("_SEARCHRESULTS","Wyniki wyszukiwania");
define("_CONTRIBUTEDBY","Wsppraca");
define("_UCOMMENTS","Komentarze");
define("_MATCHTITLE","Szukaj wedug tytuu artykuu");
define("_MATCHTEXT","Szukaj wedug tekstu");
define("_MATCHBOTH","Szukaj wedug tytyu i tekstu");
define("_SREPLY","Odpowiedz");
define("_SREPLIES","Odpowiedzi");
define("_ATTACHART","Doczony do artykuu");
define("_PAGES","Strony");
define("_REVIEWSCORE","Wynik dla tej recenzji");
define("_PAGE","Strona");

?>
